@@ -165,6 +165,8 @@ def debable(labellings,pivot,subsample_size='none'):
     return translated_list
 
 def accuracy(preds,targets,subsample_size='none',precision=4):
+    if get_num_labels(preds) == 1:
+        return np.bincounts(targets).max()
     if preds.shape != targets.shape:
         raise TranslationError(f"preds shape: {preds.shape} doesn't equal targets shape: {targets.shape}")
     if len(preds) == 0:
